
/* Generated data (by glib-mkenums) */

#ifndef EPHY_EMBED_TYPE_BUILTINS_H
#define EPHY_EMBED_TYPE_BUILTINS_H 1

#include <glib-object.h>

G_BEGIN_DECLS


/* --- ephy-embed.h --- */
#define EPHY_TYPE_EMBED_NET_STATE ephy_embed_net_state_get_type()
GType ephy_embed_net_state_get_type (void);
#define EPHY_TYPE_EMBED_CHROME ephy_embed_chrome_get_type()
GType ephy_embed_chrome_get_type (void);
#define EPHY_TYPE_EMBED_PRINT_PREVIEW_NAV_TYPE ephy_embed_print_preview_nav_type_get_type()
GType ephy_embed_print_preview_nav_type_get_type (void);
#define EPHY_TYPE_EMBED_SECURITY_LEVEL ephy_embed_security_level_get_type()
GType ephy_embed_security_level_get_type (void);
#define EPHY_TYPE_EMBED_DOCUMENT_TYPE ephy_embed_document_type_get_type()
GType ephy_embed_document_type_get_type (void);

/* --- ephy-embed-event.h --- */
#define EPHY_TYPE_EMBED_EVENT_CONTEXT ephy_embed_event_context_get_type()
GType ephy_embed_event_context_get_type (void);

/* --- ephy-embed-persist.h --- */
#define EPHY_TYPE_EMBED_PERSIST_FLAGS ephy_embed_persist_flags_get_type()
GType ephy_embed_persist_flags_get_type (void);

/* --- ephy-permission-manager.h --- */
#define EPHY_TYPE_PERMISSION ephy_permission_get_type()
GType ephy_permission_get_type (void);

/* --- ephy-x509-cert.h --- */
#define EPHY_TYPE_X509_CERT_TYPE ephy_x509_cert_type_get_type()
GType ephy_x509_cert_type_get_type (void);
G_END_DECLS

#endif /* EPHY_EMBED_TYPE_BUILTINS_H */

/* Generated data ends here */

